
	/**	@brief	check IP address input
	 *
	 *	This function do the sanity check for a IP address.
	 *	We consider the partial input values are already checked.
	 *	So, the whole IP address sanity is checked here.
	 *
	 *	@return	True/False
	 *	@retval	True	IP address input is valid
	 *	@retval False	IP address input is not valid
	 *
	 *	@param	strInput	IP address input box name
	 *	@param	strPrefix	error message prefix
	 *	@param	bMandatory	Is it mandatory (required always) ?
	 */
	function js_check_ip_addr(strInput, strPrefix, bMandatory) {
		var oInput = document.getElementsByName(strInput);
		var strError;

		/* store prefix for error message */
		if ( strPrefix ) {
			strError = strPrefix + ": ";
		} else {
			strError = "";
		}

		/* IP address input box not found */
		if ( ! oInput[0] ) {
			strError += "No such IP address input box";
			alert(strError);
			return false;
		}

		/* get IP address input value */
		var strIpAddr = oInput[0].value;

		/* no input value, it has "..." when empty */
		if ( strIpAddr.length <= 3 ) {
			if ( ! bMandatory )
				return true;

			strError += "IP address not specified";
			alert(strError);
			return false;
		}

		/* one more input box is empty */
		if ( strIpAddr.indexOf("..") >= 0
			|| strIpAddr.charAt(0) == '.'
			|| strIpAddr.charAt(strIpAddr.length-1) == '.' )
		{
			strError += "There's empty IP address input box(es)";
			alert(strError);
			return false;
		}

		/* 0.*.*.* is not allowd as a IP address,
		 * except 0.0.0.0 */
		if ( strIpAddr.charAt(0) == '0'
			&& strIpAddr.search(/[1-9]/) >= 0 )
		{
			strError += "IP address 0.*.*.* is not allowed";
			alert(strError);
			return false;
		}

		return true;
	}

